// src/editorurls-v2-editor-urls-editor.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/editorurls-v2-editor-urls-editor.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixEditorurlsV2EditorUrlsApiUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/_api/editor-urls",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/editor-urls",
        destPath: "/v2/editor-urls"
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/editorurls/v2/editor-urls",
        destPath: "/v2/editor-urls"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_urls_editor";
function getEditorUrls(payload) {
  function __getEditorUrls({ host }) {
    const metadata = {
      entityFqdn: "wix.editorurls.v2.editor_urls",
      method: "GET",
      methodFqn: "wix.editorurls.v2.EditorUrlsApi.GetEditorUrls",
      packageName: PACKAGE_NAME,
      url: resolveWixEditorurlsV2EditorUrlsApiUrl({
        protoPath: "/v2/editor-urls",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __getEditorUrls;
}

// src/editorurls-v2-editor-urls-editor.universal.ts
var EditorType = /* @__PURE__ */ ((EditorType2) => {
  EditorType2["UNKNOWN"] = "UNKNOWN";
  EditorType2["WIX_EDITOR"] = "WIX_EDITOR";
  EditorType2["EDITOR_X"] = "EDITOR_X";
  EditorType2["WIX_STUDIO"] = "WIX_STUDIO";
  EditorType2["ODEDITOR"] = "ODEDITOR";
  EditorType2["PICASSO"] = "PICASSO";
  return EditorType2;
})(EditorType || {});
async function getEditorUrls2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    branchId: options?.branchId,
    editorType: options?.editorType
  });
  const reqOpts = getEditorUrls(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          branchId: "$[0].branchId",
          editorType: "$[0].editorType"
        },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/editorurls-v2-editor-urls-editor.public.ts
function getEditorUrls3(httpClient) {
  return (options) => getEditorUrls2(
    options,
    // @ts-ignore
    { httpClient }
  );
}

// src/editorurls-v2-editor-urls-editor.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
var getEditorUrls4 = /* @__PURE__ */ createRESTModule(getEditorUrls3);
export {
  EditorType,
  getEditorUrls4 as getEditorUrls
};
//# sourceMappingURL=index.mjs.map