interface EditorUrls {
    /**
     * Editor type.
     * @readonly
     */
    editorType?: EditorTypeWithLiterals;
    /**
     * Editor URL.
     * @maxLength 2048
     * @format WEB_URL
     * @readonly
     */
    editorUrl?: string | null;
    /**
     * Preview URL.
     * @maxLength 2048
     * @format WEB_URL
     * @readonly
     */
    previewUrl?: string | null;
}
declare enum EditorType {
    /** Unknown editor type. */
    UNKNOWN = "UNKNOWN",
    /** The classic Wix Editor. */
    WIX_EDITOR = "WIX_EDITOR",
    /** Deprecated. Expected end-of-life date: July 1, 2024. */
    EDITOR_X = "EDITOR_X",
    /** Wix's Editor built for agencies and enterprises. */
    WIX_STUDIO = "WIX_STUDIO",
    /** Editor 3 */
    ODEDITOR = "ODEDITOR",
    /** Picasso */
    PICASSO = "PICASSO"
}
/** @enumType */
type EditorTypeWithLiterals = EditorType | 'UNKNOWN' | 'WIX_EDITOR' | 'EDITOR_X' | 'WIX_STUDIO' | 'ODEDITOR' | 'PICASSO';
interface GetEditorUrlsRequest {
    /**
     * Optional branch ID to include in generated URLs
     * @format GUID
     */
    branchId?: string | null;
    /** Optional editor type override */
    editorType?: EditorTypeWithLiterals;
}
interface GetEditorUrlsResponse {
    /** Editor URL. */
    urls?: EditorUrls;
}
interface GetEditorUrlsOptions {
    /**
     * Optional branch ID to include in generated URLs
     * @format GUID
     */
    branchId?: string | null;
    /** Optional editor type override */
    editorType?: EditorTypeWithLiterals;
}

export { EditorType as E, type GetEditorUrlsOptions as G, type GetEditorUrlsResponse as a, type EditorUrls as b, type GetEditorUrlsRequest as c };
